'use client';

import React, { useState } from 'react';
import path from 'path';
import fs from 'fs';
import { runMultiFileCodeWithOptionalTestData } from '@/actions/enhancedmultiFileRunner';

const TestPage = () => {
    const [code, setCode] = useState<string>('');
    const [language, setLanguage] = useState<string>('c');
    const [result, setResult] = useState<string>('');
    const [loading, setLoading] = useState<boolean>(false);

    const handleRun = async () => {
        setLoading(true);
        setResult('');

        const testFiles = [
            { name: 'input1.txt', content: '1 2 3' },
            { name: 'input2.txt', content: '4 5 6' },
        ];

        const expectedFiles = [
            { name: 'output1.txt', content: '6' },
            { name: 'output2.txt', content: '15' },
        ];

        const codeFile = {
            name: language === 'c' ? 'main.c' : language === 'python' ? 'script.py' : 'Main.java',
            content: code,
        };

        try {
            const result = await runMultiFileCodeWithOptionalTestData({
                files: [codeFile],
                language,
                testDataFiles: testFiles.map((file) => file.name),
                expectedAnswerFiles: expectedFiles.map((file) => file.name),
                resultOutputFile: 'result.txt',
            });

            setResult(JSON.stringify(result, null, 2));
        } catch (error) {
            // 使用类型断言确保 error 是 Error 类型
            setResult(`Error: ${(error as Error).message}`);
        } finally {
            setLoading(false);
        }
    };

    return (
        <div style={{ padding: '20px', fontFamily: 'Arial, sans-serif' }}>
            <h1>Test Page</h1>
            <div style={{ marginBottom: '20px' }}>
                <label>
                    <strong>Language:</strong>
                    <select
                        value={language}
                        onChange={(e) => setLanguage(e.target.value)}
                        style={{ marginLeft: '10px' }}
                    >
                        <option value="c">C</option>
                        <option value="java">Java</option>
                        <option value="python">Python</option>
                    </select>
                </label>
            </div>
            <div style={{ marginBottom: '20px' }}>
                <label>
                    <strong>Code:</strong>
                    <textarea
                        value={code}
                        onChange={(e) => setCode(e.target.value)}
                        rows={10}
                        style={{ width: '100%', fontFamily: 'monospace', fontSize: '14px' }}
                    />
                </label>
            </div>
            <button
                onClick={handleRun}
                style={{
                    padding: '10px 20px',
                    background: 'blue',
                    color: 'white',
                    border: 'none',
                    borderRadius: '5px',
                    cursor: 'pointer',
                }}
                disabled={loading}
            >
                {loading ? 'Running...' : 'Run Code'}
            </button>
            <div style={{ marginTop: '20px' }}>
                <h2>Result</h2>
                <pre
                    style={{
                        background: '#f4f4f4',
                        padding: '10px',
                        border: '1px solid #ddd',
                        borderRadius: '5px',
                    }}
                >
          {result || 'No results yet.'}
        </pre>
            </div>
        </div>
    );
};

export default TestPage;
